netapp_ontap.models.raid_group_disk API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.raid_group_disk`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class RaidGroupDiskSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the RaidGroupDisk object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `disk GET`

    The disk field of the raid_group_disk.

  `position GET`

    The position of the disk within the RAID group.

    Valid choices:

    - data
    - parity
    - dparity
    - tparity
    - copy
  `state GET`

    The state of the disk within the RAID group.

    Valid choices:

    - normal
    - failed
    - zeroing
    - copy
    - replacing
    - evacuating
    - prefail
    - offline
    - reconstructing
  `type GET`

    Disk interface type

    Valid choices:

    - ata
    - bsas
    - fcal
    - fsas
    - lun
    - sas
    - msata
    - ssd
    - vmdisk
    - unknown
    - ssd_cap
    - ssd_nvm
  `usable_size GET`

    Size in bytes that is usable by the aggregate.

    Example: 947912704